==> mpqc-2.2.3.tbz: include/scdirlist.h <==
#define HAVE_SC_BIN 1
#define HAVE_SC_DOC 1
#define HAVE_SC_LIB 1
#define HAVE_SC_LIB_BASIS 1
#define HAVE_SC_LIB_ELISP 1
#define HAVE_SC_LIB_PERL 1
#define HAVE_SC_SRC_BIN_MOLRENDER 1
#define HAVE_SC_SRC_BIN 1
#define HAVE_SC_SRC_BIN_MPQC 1
#define HAVE_SC_SRC_BIN_MPQC_VALIDATE 1
#define HAVE_SC_SRC_BIN_ORBIXME 1
#define HAVE_SC_SRC_BIN_SCLS 1
#define HAVE_SC_SRC_BIN_SCPR 1
#define HAVE_SC_SRC_LIB_CHEMISTRY_MOLECULE 1
#define HAVE_SC_SRC_LIB_CHEMISTRY 1
#define HAVE_SC_SRC_LIB_CHEMISTRY_QC_BASIS 1
#define HAVE_SC_SRC_LIB_CHEMISTRY_QC 1
#define HAVE_SC_SRC_LIB_CHEMISTRY_QC_DFT 1
#define HAVE_SC_SRC_LIB_CHEMISTRY_QC_INTV3 1
#define HAVE_SC_SRC_LIB_CHEMISTRY_QC_MBPT 1
#define HAVE_SC_SRC_LIB_CHEMISTRY_QC_OINT3 1
#define HAVE_SC_SRC_LIB_CHEMISTRY_QC_PSI 1
#define HAVE_SC_SRC_LIB_CHEMISTRY_QC_SCF 1
#define HAVE_SC_SRC_LIB_CHEMISTRY_QC_WFN 1
#define HAVE_SC_SRC_LIB_CHEMISTRY_SOLVENT 1
#define HAVE_SC_SRC_LIB 1
#define HAVE_SC_SRC_LIB_MATH_ISOSURF 1
#define HAVE_SC_SRC_LIB_MATH 1
#define HAVE_SC_SRC_LIB_MATH_LINPACKD 1
#define HAVE_SC_SRC_LIB_MATH_OPTIMIZE 1
#define HAVE_SC_SRC_LIB_MATH_SCMAT 1
#define HAVE_SC_SRC_LIB_MATH_SYMMETRY 1
#define HAVE_SC_SRC_LIB_UTIL_CLASS 1
#define HAVE_SC_SRC_LIB_UTIL 1
#define HAVE_SC_SRC_LIB_UTIL_CONTAINER 1
#define HAVE_SC_SRC_LIB_UTIL_GROUP 1
#define HAVE_SC_SRC_LIB_UTIL_KEYVAL 1
#define HAVE_SC_SRC_LIB_UTIL_MISC 1
#define HAVE_SC_SRC_LIB_UTIL_OPTIONS 1
#define HAVE_SC_SRC_LIB_UTIL_REF 1
#define HAVE_SC_SRC_LIB_UTIL_RENDER 1
#define HAVE_SC_SRC_LIB_UTIL_STATE 1
#define HAVE_SC_SRC 1

==> mpqc-2.3.1_16.tbz: include/scdirlist.h <==
#define HAVE_SC_LIB 1
#define HAVE_SC_LIB_ELISP 1
#define HAVE_SC_LIB_PERL 1
#define HAVE_SC_LIB_BASIS 1
#define HAVE_SC_SRC_BIN_MPQC_VALIDATE 1
#define HAVE_SC_SRC_BIN_MPQC 1
#define HAVE_SC_SRC_BIN_MOLRENDER 1
#define HAVE_SC_SRC_BIN 1
#define HAVE_SC_SRC_BIN_SCLS 1
#define HAVE_SC_SRC_BIN_SCPR 1
#define HAVE_SC_SRC 1
#define HAVE_SC_SRC_LIB 1
#define HAVE_SC_SRC_LIB_MATH 1
#define HAVE_SC_SRC_LIB_MATH_ISOSURF 1
#define HAVE_SC_SRC_LIB_MATH_OPTIMIZE 1
#define HAVE_SC_SRC_LIB_MATH_SCMAT 1
#define HAVE_SC_SRC_LIB_MATH_SYMMETRY 1
#define HAVE_SC_SRC_LIB_UTIL 1
#define HAVE_SC_SRC_LIB_UTIL_STATE 1
#define HAVE_SC_SRC_LIB_UTIL_PSI3 1
#define HAVE_SC_SRC_LIB_UTIL_PSI3_LIBPSIO 1
#define HAVE_SC_SRC_LIB_UTIL_GROUP 1
#define HAVE_SC_SRC_LIB_UTIL_OPTIONS 1
#define HAVE_SC_SRC_LIB_UTIL_REF 1
#define HAVE_SC_SRC_LIB_UTIL_KEYVAL 1
#define HAVE_SC_SRC_LIB_UTIL_MISC 1
#define HAVE_SC_SRC_LIB_UTIL_RENDER 1
#define HAVE_SC_SRC_LIB_UTIL_CONTAINER 1
#define HAVE_SC_SRC_LIB_UTIL_CLASS 1
#define HAVE_SC_SRC_LIB_CHEMISTRY_QC_MBPTR12 1
#define HAVE_SC_SRC_LIB_CHEMISTRY_QC 1
#define HAVE_SC_SRC_LIB_CHEMISTRY_QC_BASIS 1
#define HAVE_SC_SRC_LIB_CHEMISTRY_QC_PSI 1
#define HAVE_SC_SRC_LIB_CHEMISTRY_QC_CINTS 1
#define HAVE_SC_SRC_LIB_CHEMISTRY_QC_MBPT 1
#define HAVE_SC_SRC_LIB_CHEMISTRY_QC_WFN 1
#define HAVE_SC_SRC_LIB_CHEMISTRY_QC_OINT3 1
#define HAVE_SC_SRC_LIB_CHEMISTRY_QC_DFT 1
#define HAVE_SC_SRC_LIB_CHEMISTRY_QC_INTV3 1
#define HAVE_SC_SRC_LIB_CHEMISTRY_QC_SCF 1
#define HAVE_SC_SRC_LIB_CHEMISTRY_MOLECULE 1
#define HAVE_SC_SRC_LIB_CHEMISTRY 1
#define HAVE_SC_SRC_LIB_CHEMISTRY_SOLVENT 1
#define HAVE_SC_BIN 1
#define HAVE_SC_DOC 1
